# HWK 4 shortest path
Jackson D. Poyner

09/16/2024

This assignment is designed to demonstrate my understanding of how to create python packages and how to use git commands effectively.

You can install the package using
pip3 install graphs_jpoyner1